# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/web/interfaces/v1/interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+bilibili/web/interfaces/v1/interfaces.proto\x12\x1a\x62ilibili.web.interfaces.v1\"M\n\x07\x41\x63\x63Info\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\"\x8c\x04\n\x0b\x41\x63\x63ountCard\x12\x0b\n\x03mid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04rank\x18\x04 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x05 \x01(\t\x12\x10\n\x08spacesta\x18\x06 \x01(\x05\x12\x0c\n\x04sign\x18\x07 \x01(\t\x12=\n\nlevel_info\x18\x08 \x01(\x0b\x32).bilibili.web.interfaces.v1.CardLevelInfo\x12\x38\n\x07pendant\x18\t \x01(\x0b\x32\'.bilibili.web.interfaces.v1.PendantInfo\x12<\n\tnameplate\x18\n \x01(\x0b\x32).bilibili.web.interfaces.v1.NameplateInfo\x12:\n\x08official\x18\x0b \x01(\x0b\x32(.bilibili.web.interfaces.v1.OfficialInfo\x12\x43\n\x0fofficial_verify\x18\x0c \x01(\x0b\x32*.bilibili.web.interfaces.v1.OfficialVerify\x12\x30\n\x03vip\x18\r \x01(\x0b\x32#.bilibili.web.interfaces.v1.CardVip\x12\x0c\n\x04\x66\x61ns\x18\x0e \x01(\x03\x12\x0e\n\x06\x66riend\x18\x0f \x01(\x03\x12\x11\n\tattention\x18\x10 \x01(\x03\"\xf3\x02\n\x14\x41\x63tivityArchiveReply\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12/\n\x05pages\x18\x03 \x03(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x35\n\x08req_user\x18\x04 \x01(\x0b\x32#.bilibili.web.interfaces.v1.ReqUser\x12\x30\n\x05staff\x18\x05 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Staff\x12\x41\n\x0cright_relate\x18\x06 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x42\n\rbottom_relate\x18\x07 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\"E\n\x12\x41\x63tivityArchiveReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63tivity_key\x18\x03 \x01(\t\"\xcb\x01\n\x0f\x41\x63tivityEpisode\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x03 \x01(\t\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\r\n\x05title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x32\n\x06\x61uthor\x18\x07 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Author\x12\x32\n\x06rights\x18\x08 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Rights\"{\n\x0c\x41\x63tivityGame\x12?\n\x07iframes\x18\x01 \x03(\x0b\x32..bilibili.web.interfaces.v1.ActivityGameIframe\x12\x12\n\ndisclaimer\x18\x02 \x01(\t\x12\x16\n\x0e\x64isclaimer_url\x18\x03 \x01(\t\"1\n\x12\x41\x63tivityGameIframe\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x03\"\xf2\x02\n\x0c\x41\x63tivityLive\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x10\n\x08now_time\x18\x02 \x01(\x03\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x03\x12\x11\n\thover_pic\x18\x05 \x01(\t\x12\x16\n\x0ehover_jump_url\x18\x06 \x01(\t\x12\x13\n\x0b\x62reak_cycle\x18\x07 \x01(\x03\x12:\n\x08timeline\x18\x08 \x03(\x0b\x32(.bilibili.web.interfaces.v1.LiveTimeline\x12\x45\n\x10operation_relate\x18\t \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x12\n\nreply_type\x18\n \x01(\x03\x12\x10\n\x08reply_id\x18\x0b \x01(\x03\x12\x17\n\x0fhover_pic_close\x18\x0c \x01(\t\x12\x17\n\x0fgift_disclaimer\x18\r \x01(\t\"\x8f\x01\n\x19\x41\x63tivityLiveTimeInfoReply\x12\x10\n\x08now_time\x18\x01 \x01(\x03\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\x12:\n\x08timeline\x18\x04 \x03(\x0b\x32(.bilibili.web.interfaces.v1.LiveTimeline\"/\n\x17\x41\x63tivityLiveTimeInfoReq\x12\x14\n\x0c\x61\x63tivity_key\x18\x01 \x01(\t\"\x8a\x03\n\x13\x41\x63tivitySeasonReply\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.web.interfaces.v1.ActivitySeasonStatus\x12\r\n\x05title\x18\x02 \x01(\t\x12\x36\n\x04live\x18\x03 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ActivityLive\x12@\n\tsubscribe\x18\x04 \x01(\x0b\x32-.bilibili.web.interfaces.v1.ActivitySubscribe\x12\x36\n\x04game\x18\x05 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ActivityGame\x12\x36\n\x04view\x18\x06 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ActivityView\x12\x38\n\x05theme\x18\x07 \x01(\x0b\x32).bilibili.web.interfaces.v1.ActivityTheme\"D\n\x11\x41\x63tivitySeasonReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63tivity_key\x18\x03 \x01(\t\"\x7f\n\x15\x41\x63tivitySeasonSection\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12=\n\x08\x65pisodes\x18\x04 \x03(\x0b\x32+.bilibili.web.interfaces.v1.ActivityEpisode\"\xc2\x03\n\x11\x41\x63tivitySubscribe\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\r\n\x05title\x18\x02 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x03 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x04 \x01(\t\x12\x18\n\x10season_stat_view\x18\x05 \x01(\x03\x12\x1b\n\x13season_stat_danmaku\x18\x06 \x01(\x03\x12\x39\n\norder_type\x18\x07 \x01(\x0e\x32%.bilibili.web.interfaces.v1.OrderType\x12R\n\x16reserve_activity_param\x18\x08 \x01(\x0b\x32\x30.bilibili.web.interfaces.v1.ReserveActivityParamH\x00\x12\x46\n\x10\x66\x61v_season_param\x18\t \x01(\x0b\x32*.bilibili.web.interfaces.v1.FavSeasonParamH\x00\x12\x42\n\x0ejump_URL_param\x18\n \x01(\x0b\x32(.bilibili.web.interfaces.v1.JumpURLParamH\x00\x42\x07\n\x05param\"\x9f\x06\n\rActivityTheme\x12\x12\n\nbase_color\x18\x01 \x01(\t\x12\x18\n\x10loading_bg_color\x18\x02 \x01(\t\x12\x19\n\x11operated_bg_color\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65\x66\x61ult_element_color\x18\x04 \x01(\t\x12\x1b\n\x13hover_element_color\x18\x05 \x01(\t\x12\x1e\n\x16selected_element_color\x18\x06 \x01(\t\x12\x17\n\x0f\x62\x61se_font_color\x18\x07 \x01(\t\x12\x17\n\x0finfo_font_color\x18\x08 \x01(\t\x12\x15\n\rmask_bg_color\x18\t \x01(\t\x12\x15\n\rpage_bg_color\x18\n \x01(\t\x12\x17\n\x0f\x63\x65nter_logo_img\x18\x0b \x01(\t\x12\x13\n\x0bpage_bg_img\x18\x0c \x01(\t\x12\x1b\n\x13\x64\x65\x63orations2233_img\x18\r \x01(\t\x12\x1a\n\x12main_banner_bg_img\x18\x0e \x01(\t\x12\x1d\n\x15main_banner_title_img\x18\x0f \x01(\t\x12\x1a\n\x12like_animation_img\x18\x10 \x01(\t\x12\x16\n\x0e\x63ombo_like_img\x18\x11 \x01(\t\x12\x16\n\x0e\x63ombo_coin_img\x18\x12 \x01(\t\x12\x15\n\rcombo_fav_img\x18\x13 \x01(\t\x12\x15\n\rarrow_btn_img\x18\x14 \x01(\t\x12\x19\n\x11share_icon_bg_img\x18\x15 \x01(\t\x12\x1e\n\x16live_list_location_img\x18\x16 \x01(\t\x12%\n\x1dlive_list_location_img_active\x18\x17 \x01(\t\x12\x1a\n\x12player_loading_img\x18\x18 \x01(\t\x12\x11\n\tshare_img\x18\x19 \x01(\t\x12H\n\x08kv_color\x18\x1a \x03(\x0b\x32\x36.bilibili.web.interfaces.v1.ActivityTheme.KvColorEntry\x1a.\n\x0cKvColorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x03\n\x0c\x41\x63tivityView\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12/\n\x05pages\x18\x03 \x03(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x30\n\x05staff\x18\x04 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Staff\x12\x35\n\x08req_user\x18\x05 \x01(\x0b\x32#.bilibili.web.interfaces.v1.ReqUser\x12\x41\n\x0cright_relate\x18\x06 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x42\n\rbottom_relate\x18\x07 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x43\n\x08sections\x18\x08 \x03(\x0b\x32\x31.bilibili.web.interfaces.v1.ActivitySeasonSection\"\xdf\x05\n\x03\x41rc\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0e\n\x06videos\x18\x02 \x01(\x03\x12\x0f\n\x07type_id\x18\x03 \x01(\x05\x12\x11\n\ttype_name\x18\x04 \x01(\t\x12\x11\n\tcopyright\x18\x05 \x01(\x05\x12\x0b\n\x03pic\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07pubdate\x18\x08 \x01(\x03\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\x05\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x05\x12\x11\n\tattribute\x18\r \x01(\x05\x12\x0b\n\x03tag\x18\x0e \x01(\t\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\x10\n\x08\x64uration\x18\x10 \x01(\x03\x12\x12\n\nmission_id\x18\x11 \x01(\x03\x12\x10\n\x08order_id\x18\x12 \x01(\x03\x12\x14\n\x0credirect_url\x18\x13 \x01(\t\x12\x0f\n\x07\x66orward\x18\x14 \x01(\x03\x12\x32\n\x06rights\x18\x15 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Rights\x12\x32\n\x06\x61uthor\x18\x16 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Author\x12.\n\x04stat\x18\x17 \x01(\x0b\x32 .bilibili.web.interfaces.v1.Stat\x12\x15\n\rreport_result\x18\x18 \x01(\t\x12\x0f\n\x07\x64ynamic\x18\x19 \x01(\t\x12\x11\n\tfirst_cid\x18\x1a \x01(\x03\x12\x38\n\tdimension\x18\x1b \x01(\x0b\x32%.bilibili.web.interfaces.v1.Dimension\x12\x39\n\nstaff_info\x18\x1c \x03(\x0b\x32%.bilibili.web.interfaces.v1.StaffInfo\x12\x11\n\tseason_id\x18\x1d \x01(\x03\x12\x33\n\x07\x64\x65sc_v2\x18\x1e \x03(\x0b\x32\".bilibili.web.interfaces.v1.DescV2\"1\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\"\xc2\x01\n\x04\x43\x61rd\x12\x35\n\x04\x63\x61rd\x18\x01 \x01(\x0b\x32\'.bilibili.web.interfaces.v1.AccountCard\x12\x30\n\x05space\x18\x02 \x01(\x0b\x32!.bilibili.web.interfaces.v1.Space\x12\x11\n\tfollowing\x18\x03 \x01(\x08\x12\x15\n\rarchive_count\x18\x04 \x01(\x03\x12\x15\n\rarticle_count\x18\x05 \x01(\x05\x12\x10\n\x08\x66ollower\x18\x06 \x01(\x03\"L\n\rCardLevelInfo\x12\x0b\n\x03\x63ur\x18\x01 \x01(\x05\x12\x0b\n\x03min\x18\x02 \x01(\x05\x12\x0f\n\x07now_exp\x18\x03 \x01(\x05\x12\x10\n\x08next_exp\x18\x04 \x01(\x05\"\x83\x01\n\x07\x43\x61rdVip\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x12\n\ndue_remark\x18\x02 \x01(\t\x12\x15\n\raccess_status\x18\x03 \x01(\x05\x12\x12\n\nvip_status\x18\x04 \x01(\x05\x12\x17\n\x0fvip_status_warn\x18\x05 \x01(\t\x12\x12\n\ntheme_type\x18\x06 \x01(\x05\"\xdb\x02\n\x16\x43lickActivitySeasonReq\x12\x39\n\norder_type\x18\x01 \x01(\x0e\x32%.bilibili.web.interfaces.v1.OrderType\x12R\n\x16reserve_activity_param\x18\x02 \x01(\x0b\x32\x30.bilibili.web.interfaces.v1.ReserveActivityParamH\x00\x12\x46\n\x10\x66\x61v_season_param\x18\x03 \x01(\x0b\x32*.bilibili.web.interfaces.v1.FavSeasonParamH\x00\x12\x42\n\x0ejump_URL_param\x18\x04 \x01(\x0b\x32(.bilibili.web.interfaces.v1.JumpURLParamH\x00\x12\r\n\x05spmid\x18\x05 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x06 \x01(\x03\x42\x07\n\x05param\"8\n\x06\x44\x65scV2\x12\x10\n\x08raw_text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0e\n\x06\x62iz_id\x18\x03 \x01(\x03\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"#\n\x0e\x46\x61vSeasonParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"s\n\x08HotReply\x12\x33\n\x04page\x18\x01 \x01(\x0b\x32%.bilibili.web.interfaces.v1.ReplyPage\x12\x32\n\x07replies\x18\x02 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Reply\" \n\x0cJumpURLParam\x12\x10\n\x08jump_url\x18\x01 \x01(\t\"u\n\x0cLiveTimeline\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08subtitle\x18\x05 \x01(\t\x12\x10\n\x08h5_cover\x18\x06 \x01(\t\"p\n\rNameplateInfo\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"\t\n\x07NoReply\"9\n\x0cOfficialInfo\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"\x99\x01\n\x0fOperationRelate\x12\r\n\x05title\x18\x01 \x01(\t\x12;\n\x0brelate_item\x18\x02 \x03(\x0b\x32&.bilibili.web.interfaces.v1.RelateItem\x12:\n\x0e\x61i_relate_item\x18\x03 \x03(\x0b\x32\".bilibili.web.interfaces.v1.Relate\"\xb5\x01\n\x04Page\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0c\n\x04part\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03vid\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x07 \x01(\t\x12\x0f\n\x07weblink\x18\x08 \x01(\t\x12\x38\n\tdimension\x18\t \x01(\x0b\x32%.bilibili.web.interfaces.v1.Dimension\"G\n\x0bPendantInfo\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"Y\n\x06Relate\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x13\n\x0bseason_type\x18\x03 \x01(\x03\"(\n\nRelateItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\".\n\x08Relation\x12\x11\n\tattribute\x18\x01 \x01(\x03\x12\x0f\n\x07special\x18\x03 \x01(\x03\"\xdf\x05\n\x05Reply\x12\x0c\n\x04rpid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\x0c\n\x04root\x18\x05 \x01(\x03\x12\x0e\n\x06parent\x18\x06 \x01(\x03\x12\x0e\n\x06\x64ialog\x18\x07 \x01(\x03\x12\r\n\x05\x63ount\x18\x08 \x01(\x05\x12\x0e\n\x06rcount\x18\t \x01(\x05\x12\r\n\x05\x66loor\x18\n \x01(\x05\x12\r\n\x05state\x18\x0b \x01(\x05\x12\x12\n\nfans_grade\x18\x0c \x01(\x05\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\x12\r\n\x05\x63time\x18\x0e \x01(\x03\x12\x10\n\x08rpid_str\x18\x0f \x01(\t\x12\x10\n\x08root_str\x18\x10 \x01(\t\x12\x12\n\nparent_str\x18\x11 \x01(\t\x12\x12\n\ndialog_str\x18\x12 \x01(\t\x12\x0c\n\x04like\x18\x13 \x01(\x05\x12\x0c\n\x04hate\x18\x14 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x15 \x01(\x05\x12\x37\n\x06member\x18\x16 \x01(\x0b\x32\'.bilibili.web.interfaces.v1.ReplyMember\x12\x39\n\x07\x63ontent\x18\x17 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ReplyContent\x12\x32\n\x07replies\x18\x18 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Reply\x12\x0e\n\x06\x61ssist\x18\x19 \x01(\x05\x12\x37\n\x06\x66older\x18\x1a \x01(\x0b\x32\'.bilibili.web.interfaces.v1.ReplyFolder\x12<\n\tup_action\x18\x1b \x01(\x0b\x32).bilibili.web.interfaces.v1.ReplyUpAction\x12\x35\n\x05label\x18\x1c \x01(\x0b\x32&.bilibili.web.interfaces.v1.ReplyLabel\x12\x11\n\traw_input\x18\x1d \x01(\t\x12\x13\n\x0bshow_follow\x18\x1e \x01(\x08\"\x86\x03\n\x0cReplyContent\x12\r\n\x05rp_id\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x33\n\x04vote\x18\x03 \x01(\x0b\x32%.bilibili.web.interfaces.v1.ReplyVote\x12\x0e\n\x06topics\x18\x05 \x03(\t\x12\n\n\x02ip\x18\x06 \x01(\x05\x12\x0c\n\x04plat\x18\x07 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12<\n\x07members\x18\n \x03(\x0b\x32+.bilibili.web.interfaces.v1.ReplyMemberInfo\x12\x42\n\x05\x65mote\x18\x0b \x03(\x0b\x32\x33.bilibili.web.interfaces.v1.ReplyContent.EmoteEntry\x1aT\n\nEmoteEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.bilibili.web.interfaces.v1.ReplyEmote:\x02\x38\x01\"\xca\x01\n\nReplyEmote\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x12\n\npackage_id\x18\x02 \x01(\x03\x12\r\n\x05state\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12\x0c\n\x04\x61ttr\x18\x05 \x01(\x03\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\x12\x38\n\x04meta\x18\x08 \x01(\x0b\x32*.bilibili.web.interfaces.v1.ReplyEmoteMeta\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\r\n\x05mtime\x18\n \x01(\x03\"N\n\x0eReplyEmoteMeta\x12<\n\x04size\x18\x01 \x01(\x0e\x32..bilibili.web.interfaces.v1.ReplyEmoteMetaSize\"\x96\x01\n\x0fReplyFansDetail\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x10\n\x08medal_id\x18\x02 \x01(\x05\x12\x12\n\nmedal_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x05\x12\r\n\x05level\x18\x05 \x01(\x05\x12\x10\n\x08intimacy\x18\x06 \x01(\x05\x12\x0e\n\x06status\x18\x07 \x01(\x05\x12\x10\n\x08received\x18\x08 \x01(\x05\"B\n\x0bReplyFolder\x12\x12\n\nhas_folded\x18\x01 \x01(\x08\x12\x11\n\tis_folded\x18\x02 \x01(\x08\x12\x0c\n\x04rule\x18\x03 \x01(\t\"\xad\x01\n\nReplyLabel\x12\x0c\n\x04rpid\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\x12\x1d\n\x15text_color_night_mode\x18\x04 \x01(\t\x12\x10\n\x08\x62g_color\x18\x05 \x01(\t\x12\x1b\n\x13\x62g_color_night_mode\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\x10\n\x08position\x18\x08 \x01(\t\"M\n\x0eReplyLevelInfo\x12\x0b\n\x03\x63ur\x18\x01 \x01(\x05\x12\x0b\n\x03min\x18\x02 \x01(\x05\x12\x0f\n\x07now_exp\x18\x03 \x01(\x05\x12\x10\n\x08next_exp\x18\x04 \x01(\x05\"\x9d\x01\n\x0bReplyMember\x12\x39\n\x04info\x18\x01 \x01(\x0b\x32+.bilibili.web.interfaces.v1.ReplyMemberInfo\x12@\n\x0b\x66\x61ns_detail\x18\x02 \x01(\x0b\x32+.bilibili.web.interfaces.v1.ReplyFansDetail\x12\x11\n\tfollowing\x18\x03 \x01(\x05\"\xb9\x03\n\x0fReplyMemberInfo\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\x0b\n\x03mid\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03sex\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x06 \x01(\t\x12\x0c\n\x04rank\x18\x07 \x01(\t\x12\x14\n\x0c\x64isplay_rank\x18\x08 \x01(\t\x12>\n\nlevel_info\x18\t \x01(\x0b\x32*.bilibili.web.interfaces.v1.ReplyLevelInfo\x12\x38\n\x07pendant\x18\n \x01(\x0b\x32\'.bilibili.web.interfaces.v1.PendantInfo\x12<\n\tnameplate\x18\x0b \x01(\x0b\x32).bilibili.web.interfaces.v1.NameplateInfo\x12\x43\n\x0fofficial_verify\x18\x0c \x01(\x0b\x32*.bilibili.web.interfaces.v1.OfficialVerify\x12\x31\n\x03vip\x18\r \x01(\x0b\x32$.bilibili.web.interfaces.v1.ReplyVip\"E\n\tReplyPage\x12\x0e\n\x06\x61\x63ount\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x0b\n\x03num\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x03\",\n\rReplyUpAction\x12\x0c\n\x04like\x18\x01 \x01(\x08\x12\r\n\x05reply\x18\x02 \x01(\x08\"\xcb\x01\n\x08ReplyVip\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x02 \x01(\x03\x12\x12\n\ndue_remark\x18\x03 \x01(\t\x12\x15\n\raccess_status\x18\x04 \x01(\x05\x12\x12\n\nvip_status\x18\x05 \x01(\x05\x12\x17\n\x0fvip_status_warn\x18\x06 \x01(\t\x12\x12\n\ntheme_type\x18\x07 \x01(\x05\x12\x33\n\x05label\x18\x08 \x01(\x0b\x32$.bilibili.web.interfaces.v1.VipLabel\"R\n\tReplyVote\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63nt\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08\"L\n\x07ReqUser\x12\x10\n\x08\x66\x61vorite\x18\x01 \x01(\x08\x12\x0c\n\x04like\x18\x02 \x01(\x08\x12\x0f\n\x07\x64islike\x18\x03 \x01(\x08\x12\x10\n\x08multiply\x18\x04 \x01(\x03\"S\n\x14ReserveActivityParam\x12\x12\n\nreserve_id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\x03\"\xc5\x01\n\x06Rights\x12\n\n\x02\x62p\x18\x01 \x01(\x05\x12\x0c\n\x04\x65lec\x18\x02 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x03 \x01(\x05\x12\r\n\x05movie\x18\x04 \x01(\x05\x12\x0b\n\x03pay\x18\x05 \x01(\x05\x12\x0b\n\x03hd5\x18\x06 \x01(\x05\x12\x12\n\nno_reprint\x18\x07 \x01(\x05\x12\x10\n\x08\x61utoplay\x18\x08 \x01(\x05\x12\x0f\n\x07ugc_pay\x18\t \x01(\x05\x12\x16\n\x0eis_cooperation\x18\n \x01(\x05\x12\x17\n\x0fugc_pay_preview\x18\x0b \x01(\x05\"\xea\x01\n\rSeasonEpisode\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x12\n\nsection_id\x18\x02 \x01(\x03\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\x11\n\tattribute\x18\x07 \x01(\x03\x12,\n\x03\x61rc\x18\x08 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12.\n\x04page\x18\t \x01(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x0c\n\x04\x62vid\x18\n \x01(\t\"\x88\x01\n\rSeasonSection\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12;\n\x08\x65pisodes\x18\x05 \x03(\x0b\x32).bilibili.web.interfaces.v1.SeasonEpisode\"\xa9\x01\n\nSeasonStat\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\"%\n\x05Space\x12\r\n\x05s_img\x18\x01 \x01(\t\x12\r\n\x05l_img\x18\x02 \x01(\t\"\x8c\x02\n\x05Staff\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x30\n\x03vip\x18\x05 \x01(\x0b\x32#.bilibili.web.interfaces.v1.VipInfo\x12:\n\x08official\x18\x06 \x01(\x0b\x32(.bilibili.web.interfaces.v1.OfficialInfo\x12\x10\n\x08\x66ollower\x18\x07 \x01(\x03\x12\x13\n\x0blabel_style\x18\x08 \x01(\x05\x12\x36\n\x08relation\x18\t \x01(\x0b\x32$.bilibili.web.interfaces.v1.Relation\"\'\n\tStaffInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\"\xd5\x01\n\x04Stat\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\x12\x0f\n\x07\x64islike\x18\x0b \x01(\x05\x12\x12\n\nevaluation\x18\x0c \x01(\t\x12\x11\n\targue_msg\x18\r \x01(\t\"X\n\x08Subtitle\x12\x14\n\x0c\x61llow_submit\x18\x01 \x01(\x08\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.bilibili.web.interfaces.v1.SubtitleItem\"\xa8\x01\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03lan\x18\x02 \x01(\t\x12\x0f\n\x07lan_doc\x18\x03 \x01(\t\x12\x0f\n\x07is_lock\x18\x04 \x01(\x08\x12\x12\n\nauthor_mid\x18\x05 \x01(\x03\x12\x14\n\x0csubtitle_url\x18\x06 \x01(\t\x12\x33\n\x06\x61uthor\x18\x07 \x01(\x0b\x32#.bilibili.web.interfaces.v1.AccInfo\"\xb0\x02\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x12\n\nhead_cover\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x15\n\rshort_content\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\r\n\x05state\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\x37\n\ttag_count\x18\n \x01(\x0b\x32$.bilibili.web.interfaces.v1.TagCount\x12\x10\n\x08is_atten\x18\x0b \x01(\x05\x12\r\n\x05likes\x18\x0c \x01(\x03\x12\r\n\x05hates\x18\r \x01(\x03\x12\x11\n\tattribute\x18\x0e \x01(\x05\x12\r\n\x05liked\x18\x0f \x01(\x05\x12\r\n\x05hated\x18\x10 \x01(\x05\"4\n\x08TagCount\x12\x0c\n\x04view\x18\x01 \x01(\x03\x12\x0b\n\x03use\x18\x02 \x01(\x03\x12\r\n\x05\x61tten\x18\x03 \x01(\x03\"\xa6\x01\n\x0bUGCPayAsset\x12\r\n\x05price\x18\x01 \x01(\x03\x12R\n\x0eplatform_price\x18\x02 \x03(\x0b\x32:.bilibili.web.interfaces.v1.UGCPayAsset.PlatformPriceEntry\x1a\x34\n\x12PlatformPriceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x92\x02\n\tUGCSeason\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\r\n\x05intro\x18\x05 \x01(\t\x12\x12\n\nsign_state\x18\x06 \x01(\x05\x12\x11\n\tattribute\x18\x07 \x01(\x03\x12;\n\x08sections\x18\x08 \x03(\x0b\x32).bilibili.web.interfaces.v1.SeasonSection\x12\x34\n\x04stat\x18\t \x01(\x0b\x32&.bilibili.web.interfaces.v1.SeasonStat\x12\x10\n\x08\x65p_count\x18\n \x01(\x03\x12\x13\n\x0bseason_type\x18\x0b \x01(\x03\"\xa3\x03\n\x04View\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x10\n\x08no_cache\x18\x02 \x01(\x08\x12/\n\x05pages\x18\x03 \x03(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x36\n\x08subtitle\x18\x04 \x01(\x0b\x32$.bilibili.web.interfaces.v1.Subtitle\x12\x36\n\x05\x61sset\x18\x05 \x01(\x0b\x32\'.bilibili.web.interfaces.v1.UGCPayAsset\x12\x34\n\x05label\x18\x06 \x01(\x0b\x32%.bilibili.web.interfaces.v1.ViewLabel\x12\x30\n\x05staff\x18\x07 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Staff\x12\x39\n\nugc_season\x18\x08 \x01(\x0b\x32%.bilibili.web.interfaces.v1.UGCSeason\x12\x17\n\x0fstein_guide_cid\x18\t \x01(\x03\"\x87\x02\n\x0fViewDetailReply\x12.\n\x04view\x18\x01 \x01(\x0b\x32 .bilibili.web.interfaces.v1.View\x12.\n\x04\x63\x61rd\x18\x02 \x01(\x0b\x32 .bilibili.web.interfaces.v1.Card\x12-\n\x04tags\x18\x03 \x03(\x0b\x32\x1f.bilibili.web.interfaces.v1.Tag\x12\x33\n\x05reply\x18\x04 \x01(\x0b\x32$.bilibili.web.interfaces.v1.HotReply\x12\x30\n\x07related\x18\x05 \x03(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\"*\n\rViewDetailReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\"\x19\n\tViewLabel\x12\x0c\n\x04type\x18\x01 \x01(\x03\"Q\n\x07VipInfo\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x14\n\x0cvip_pay_type\x18\x03 \x01(\x05\x12\x12\n\ntheme_type\x18\x04 \x01(\x05\"\x18\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t*F\n\x14\x41\x63tivitySeasonStatus\x12\x0e\n\nStatusNone\x10\x00\x12\x0e\n\nStatusLive\x10\x01\x12\x0e\n\nStatusView\x10\x02*R\n\tOrderType\x12\x0c\n\x08TypeNone\x10\x00\x12\x15\n\x11TypeOrderActivity\x10\x01\x12\x11\n\rTypeFavSeason\x10\x02\x12\r\n\tTypeClick\x10\x03*i\n\x12ReplyEmoteMetaSize\x12\x1f\n\x1b\x45MOTE_META_SIZE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45MOTE_META_SIZE_SMALL\x10\x01\x12\x17\n\x13\x45MOTE_META_SIZE_BIG\x10\x02\x62\x06proto3')

_ACTIVITYSEASONSTATUS = DESCRIPTOR.enum_types_by_name['ActivitySeasonStatus']
ActivitySeasonStatus = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYSEASONSTATUS)
_ORDERTYPE = DESCRIPTOR.enum_types_by_name['OrderType']
OrderType = enum_type_wrapper.EnumTypeWrapper(_ORDERTYPE)
_REPLYEMOTEMETASIZE = DESCRIPTOR.enum_types_by_name['ReplyEmoteMetaSize']
ReplyEmoteMetaSize = enum_type_wrapper.EnumTypeWrapper(_REPLYEMOTEMETASIZE)
StatusNone = 0
StatusLive = 1
StatusView = 2
TypeNone = 0
TypeOrderActivity = 1
TypeFavSeason = 2
TypeClick = 3
EMOTE_META_SIZE_UNSPECIFIED = 0
EMOTE_META_SIZE_SMALL = 1
EMOTE_META_SIZE_BIG = 2


_ACCINFO = DESCRIPTOR.message_types_by_name['AccInfo']
_ACCOUNTCARD = DESCRIPTOR.message_types_by_name['AccountCard']
_ACTIVITYARCHIVEREPLY = DESCRIPTOR.message_types_by_name['ActivityArchiveReply']
_ACTIVITYARCHIVEREQ = DESCRIPTOR.message_types_by_name['ActivityArchiveReq']
_ACTIVITYEPISODE = DESCRIPTOR.message_types_by_name['ActivityEpisode']
_ACTIVITYGAME = DESCRIPTOR.message_types_by_name['ActivityGame']
_ACTIVITYGAMEIFRAME = DESCRIPTOR.message_types_by_name['ActivityGameIframe']
_ACTIVITYLIVE = DESCRIPTOR.message_types_by_name['ActivityLive']
_ACTIVITYLIVETIMEINFOREPLY = DESCRIPTOR.message_types_by_name['ActivityLiveTimeInfoReply']
_ACTIVITYLIVETIMEINFOREQ = DESCRIPTOR.message_types_by_name['ActivityLiveTimeInfoReq']
_ACTIVITYSEASONREPLY = DESCRIPTOR.message_types_by_name['ActivitySeasonReply']
_ACTIVITYSEASONREQ = DESCRIPTOR.message_types_by_name['ActivitySeasonReq']
_ACTIVITYSEASONSECTION = DESCRIPTOR.message_types_by_name['ActivitySeasonSection']
_ACTIVITYSUBSCRIBE = DESCRIPTOR.message_types_by_name['ActivitySubscribe']
_ACTIVITYTHEME = DESCRIPTOR.message_types_by_name['ActivityTheme']
_ACTIVITYTHEME_KVCOLORENTRY = _ACTIVITYTHEME.nested_types_by_name['KvColorEntry']
_ACTIVITYVIEW = DESCRIPTOR.message_types_by_name['ActivityView']
_ARC = DESCRIPTOR.message_types_by_name['Arc']
_AUTHOR = DESCRIPTOR.message_types_by_name['Author']
_CARD = DESCRIPTOR.message_types_by_name['Card']
_CARDLEVELINFO = DESCRIPTOR.message_types_by_name['CardLevelInfo']
_CARDVIP = DESCRIPTOR.message_types_by_name['CardVip']
_CLICKACTIVITYSEASONREQ = DESCRIPTOR.message_types_by_name['ClickActivitySeasonReq']
_DESCV2 = DESCRIPTOR.message_types_by_name['DescV2']
_DIMENSION = DESCRIPTOR.message_types_by_name['Dimension']
_FAVSEASONPARAM = DESCRIPTOR.message_types_by_name['FavSeasonParam']
_HOTREPLY = DESCRIPTOR.message_types_by_name['HotReply']
_JUMPURLPARAM = DESCRIPTOR.message_types_by_name['JumpURLParam']
_LIVETIMELINE = DESCRIPTOR.message_types_by_name['LiveTimeline']
_NAMEPLATEINFO = DESCRIPTOR.message_types_by_name['NameplateInfo']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_OFFICIALINFO = DESCRIPTOR.message_types_by_name['OfficialInfo']
_OFFICIALVERIFY = DESCRIPTOR.message_types_by_name['OfficialVerify']
_OPERATIONRELATE = DESCRIPTOR.message_types_by_name['OperationRelate']
_PAGE = DESCRIPTOR.message_types_by_name['Page']
_PENDANTINFO = DESCRIPTOR.message_types_by_name['PendantInfo']
_RELATE = DESCRIPTOR.message_types_by_name['Relate']
_RELATEITEM = DESCRIPTOR.message_types_by_name['RelateItem']
_RELATION = DESCRIPTOR.message_types_by_name['Relation']
_REPLY = DESCRIPTOR.message_types_by_name['Reply']
_REPLYCONTENT = DESCRIPTOR.message_types_by_name['ReplyContent']
_REPLYCONTENT_EMOTEENTRY = _REPLYCONTENT.nested_types_by_name['EmoteEntry']
_REPLYEMOTE = DESCRIPTOR.message_types_by_name['ReplyEmote']
_REPLYEMOTEMETA = DESCRIPTOR.message_types_by_name['ReplyEmoteMeta']
_REPLYFANSDETAIL = DESCRIPTOR.message_types_by_name['ReplyFansDetail']
_REPLYFOLDER = DESCRIPTOR.message_types_by_name['ReplyFolder']
_REPLYLABEL = DESCRIPTOR.message_types_by_name['ReplyLabel']
_REPLYLEVELINFO = DESCRIPTOR.message_types_by_name['ReplyLevelInfo']
_REPLYMEMBER = DESCRIPTOR.message_types_by_name['ReplyMember']
_REPLYMEMBERINFO = DESCRIPTOR.message_types_by_name['ReplyMemberInfo']
_REPLYPAGE = DESCRIPTOR.message_types_by_name['ReplyPage']
_REPLYUPACTION = DESCRIPTOR.message_types_by_name['ReplyUpAction']
_REPLYVIP = DESCRIPTOR.message_types_by_name['ReplyVip']
_REPLYVOTE = DESCRIPTOR.message_types_by_name['ReplyVote']
_REQUSER = DESCRIPTOR.message_types_by_name['ReqUser']
_RESERVEACTIVITYPARAM = DESCRIPTOR.message_types_by_name['ReserveActivityParam']
_RIGHTS = DESCRIPTOR.message_types_by_name['Rights']
_SEASONEPISODE = DESCRIPTOR.message_types_by_name['SeasonEpisode']
_SEASONSECTION = DESCRIPTOR.message_types_by_name['SeasonSection']
_SEASONSTAT = DESCRIPTOR.message_types_by_name['SeasonStat']
_SPACE = DESCRIPTOR.message_types_by_name['Space']
_STAFF = DESCRIPTOR.message_types_by_name['Staff']
_STAFFINFO = DESCRIPTOR.message_types_by_name['StaffInfo']
_STAT = DESCRIPTOR.message_types_by_name['Stat']
_SUBTITLE = DESCRIPTOR.message_types_by_name['Subtitle']
_SUBTITLEITEM = DESCRIPTOR.message_types_by_name['SubtitleItem']
_TAG = DESCRIPTOR.message_types_by_name['Tag']
_TAGCOUNT = DESCRIPTOR.message_types_by_name['TagCount']
_UGCPAYASSET = DESCRIPTOR.message_types_by_name['UGCPayAsset']
_UGCPAYASSET_PLATFORMPRICEENTRY = _UGCPAYASSET.nested_types_by_name['PlatformPriceEntry']
_UGCSEASON = DESCRIPTOR.message_types_by_name['UGCSeason']
_VIEW = DESCRIPTOR.message_types_by_name['View']
_VIEWDETAILREPLY = DESCRIPTOR.message_types_by_name['ViewDetailReply']
_VIEWDETAILREQ = DESCRIPTOR.message_types_by_name['ViewDetailReq']
_VIEWLABEL = DESCRIPTOR.message_types_by_name['ViewLabel']
_VIPINFO = DESCRIPTOR.message_types_by_name['VipInfo']
_VIPLABEL = DESCRIPTOR.message_types_by_name['VipLabel']
AccInfo = _reflection.GeneratedProtocolMessageType('AccInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACCINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.AccInfo)
  })
_sym_db.RegisterMessage(AccInfo)

AccountCard = _reflection.GeneratedProtocolMessageType('AccountCard', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCARD,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.AccountCard)
  })
_sym_db.RegisterMessage(AccountCard)

ActivityArchiveReply = _reflection.GeneratedProtocolMessageType('ActivityArchiveReply', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYARCHIVEREPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityArchiveReply)
  })
_sym_db.RegisterMessage(ActivityArchiveReply)

ActivityArchiveReq = _reflection.GeneratedProtocolMessageType('ActivityArchiveReq', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYARCHIVEREQ,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityArchiveReq)
  })
_sym_db.RegisterMessage(ActivityArchiveReq)

ActivityEpisode = _reflection.GeneratedProtocolMessageType('ActivityEpisode', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYEPISODE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityEpisode)
  })
_sym_db.RegisterMessage(ActivityEpisode)

ActivityGame = _reflection.GeneratedProtocolMessageType('ActivityGame', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYGAME,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityGame)
  })
_sym_db.RegisterMessage(ActivityGame)

ActivityGameIframe = _reflection.GeneratedProtocolMessageType('ActivityGameIframe', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYGAMEIFRAME,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityGameIframe)
  })
_sym_db.RegisterMessage(ActivityGameIframe)

ActivityLive = _reflection.GeneratedProtocolMessageType('ActivityLive', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLIVE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityLive)
  })
_sym_db.RegisterMessage(ActivityLive)

ActivityLiveTimeInfoReply = _reflection.GeneratedProtocolMessageType('ActivityLiveTimeInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLIVETIMEINFOREPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityLiveTimeInfoReply)
  })
_sym_db.RegisterMessage(ActivityLiveTimeInfoReply)

ActivityLiveTimeInfoReq = _reflection.GeneratedProtocolMessageType('ActivityLiveTimeInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYLIVETIMEINFOREQ,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityLiveTimeInfoReq)
  })
_sym_db.RegisterMessage(ActivityLiveTimeInfoReq)

ActivitySeasonReply = _reflection.GeneratedProtocolMessageType('ActivitySeasonReply', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSEASONREPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivitySeasonReply)
  })
_sym_db.RegisterMessage(ActivitySeasonReply)

ActivitySeasonReq = _reflection.GeneratedProtocolMessageType('ActivitySeasonReq', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSEASONREQ,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivitySeasonReq)
  })
_sym_db.RegisterMessage(ActivitySeasonReq)

ActivitySeasonSection = _reflection.GeneratedProtocolMessageType('ActivitySeasonSection', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSEASONSECTION,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivitySeasonSection)
  })
_sym_db.RegisterMessage(ActivitySeasonSection)

ActivitySubscribe = _reflection.GeneratedProtocolMessageType('ActivitySubscribe', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSUBSCRIBE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivitySubscribe)
  })
_sym_db.RegisterMessage(ActivitySubscribe)

ActivityTheme = _reflection.GeneratedProtocolMessageType('ActivityTheme', (_message.Message,), {

  'KvColorEntry' : _reflection.GeneratedProtocolMessageType('KvColorEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACTIVITYTHEME_KVCOLORENTRY,
    '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityTheme.KvColorEntry)
    })
  ,
  'DESCRIPTOR' : _ACTIVITYTHEME,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityTheme)
  })
_sym_db.RegisterMessage(ActivityTheme)
_sym_db.RegisterMessage(ActivityTheme.KvColorEntry)

ActivityView = _reflection.GeneratedProtocolMessageType('ActivityView', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYVIEW,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ActivityView)
  })
_sym_db.RegisterMessage(ActivityView)

Arc = _reflection.GeneratedProtocolMessageType('Arc', (_message.Message,), {
  'DESCRIPTOR' : _ARC,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Arc)
  })
_sym_db.RegisterMessage(Arc)

Author = _reflection.GeneratedProtocolMessageType('Author', (_message.Message,), {
  'DESCRIPTOR' : _AUTHOR,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Author)
  })
_sym_db.RegisterMessage(Author)

Card = _reflection.GeneratedProtocolMessageType('Card', (_message.Message,), {
  'DESCRIPTOR' : _CARD,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Card)
  })
_sym_db.RegisterMessage(Card)

CardLevelInfo = _reflection.GeneratedProtocolMessageType('CardLevelInfo', (_message.Message,), {
  'DESCRIPTOR' : _CARDLEVELINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.CardLevelInfo)
  })
_sym_db.RegisterMessage(CardLevelInfo)

CardVip = _reflection.GeneratedProtocolMessageType('CardVip', (_message.Message,), {
  'DESCRIPTOR' : _CARDVIP,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.CardVip)
  })
_sym_db.RegisterMessage(CardVip)

ClickActivitySeasonReq = _reflection.GeneratedProtocolMessageType('ClickActivitySeasonReq', (_message.Message,), {
  'DESCRIPTOR' : _CLICKACTIVITYSEASONREQ,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ClickActivitySeasonReq)
  })
_sym_db.RegisterMessage(ClickActivitySeasonReq)

DescV2 = _reflection.GeneratedProtocolMessageType('DescV2', (_message.Message,), {
  'DESCRIPTOR' : _DESCV2,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.DescV2)
  })
_sym_db.RegisterMessage(DescV2)

Dimension = _reflection.GeneratedProtocolMessageType('Dimension', (_message.Message,), {
  'DESCRIPTOR' : _DIMENSION,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Dimension)
  })
_sym_db.RegisterMessage(Dimension)

FavSeasonParam = _reflection.GeneratedProtocolMessageType('FavSeasonParam', (_message.Message,), {
  'DESCRIPTOR' : _FAVSEASONPARAM,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.FavSeasonParam)
  })
_sym_db.RegisterMessage(FavSeasonParam)

HotReply = _reflection.GeneratedProtocolMessageType('HotReply', (_message.Message,), {
  'DESCRIPTOR' : _HOTREPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.HotReply)
  })
_sym_db.RegisterMessage(HotReply)

JumpURLParam = _reflection.GeneratedProtocolMessageType('JumpURLParam', (_message.Message,), {
  'DESCRIPTOR' : _JUMPURLPARAM,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.JumpURLParam)
  })
_sym_db.RegisterMessage(JumpURLParam)

LiveTimeline = _reflection.GeneratedProtocolMessageType('LiveTimeline', (_message.Message,), {
  'DESCRIPTOR' : _LIVETIMELINE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.LiveTimeline)
  })
_sym_db.RegisterMessage(LiveTimeline)

NameplateInfo = _reflection.GeneratedProtocolMessageType('NameplateInfo', (_message.Message,), {
  'DESCRIPTOR' : _NAMEPLATEINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.NameplateInfo)
  })
_sym_db.RegisterMessage(NameplateInfo)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

OfficialInfo = _reflection.GeneratedProtocolMessageType('OfficialInfo', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.OfficialInfo)
  })
_sym_db.RegisterMessage(OfficialInfo)

OfficialVerify = _reflection.GeneratedProtocolMessageType('OfficialVerify', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALVERIFY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.OfficialVerify)
  })
_sym_db.RegisterMessage(OfficialVerify)

OperationRelate = _reflection.GeneratedProtocolMessageType('OperationRelate', (_message.Message,), {
  'DESCRIPTOR' : _OPERATIONRELATE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.OperationRelate)
  })
_sym_db.RegisterMessage(OperationRelate)

Page = _reflection.GeneratedProtocolMessageType('Page', (_message.Message,), {
  'DESCRIPTOR' : _PAGE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Page)
  })
_sym_db.RegisterMessage(Page)

PendantInfo = _reflection.GeneratedProtocolMessageType('PendantInfo', (_message.Message,), {
  'DESCRIPTOR' : _PENDANTINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.PendantInfo)
  })
_sym_db.RegisterMessage(PendantInfo)

Relate = _reflection.GeneratedProtocolMessageType('Relate', (_message.Message,), {
  'DESCRIPTOR' : _RELATE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Relate)
  })
_sym_db.RegisterMessage(Relate)

RelateItem = _reflection.GeneratedProtocolMessageType('RelateItem', (_message.Message,), {
  'DESCRIPTOR' : _RELATEITEM,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.RelateItem)
  })
_sym_db.RegisterMessage(RelateItem)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Relation)
  })
_sym_db.RegisterMessage(Relation)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Reply)
  })
_sym_db.RegisterMessage(Reply)

ReplyContent = _reflection.GeneratedProtocolMessageType('ReplyContent', (_message.Message,), {

  'EmoteEntry' : _reflection.GeneratedProtocolMessageType('EmoteEntry', (_message.Message,), {
    'DESCRIPTOR' : _REPLYCONTENT_EMOTEENTRY,
    '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyContent.EmoteEntry)
    })
  ,
  'DESCRIPTOR' : _REPLYCONTENT,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyContent)
  })
_sym_db.RegisterMessage(ReplyContent)
_sym_db.RegisterMessage(ReplyContent.EmoteEntry)

ReplyEmote = _reflection.GeneratedProtocolMessageType('ReplyEmote', (_message.Message,), {
  'DESCRIPTOR' : _REPLYEMOTE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyEmote)
  })
_sym_db.RegisterMessage(ReplyEmote)

ReplyEmoteMeta = _reflection.GeneratedProtocolMessageType('ReplyEmoteMeta', (_message.Message,), {
  'DESCRIPTOR' : _REPLYEMOTEMETA,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyEmoteMeta)
  })
_sym_db.RegisterMessage(ReplyEmoteMeta)

ReplyFansDetail = _reflection.GeneratedProtocolMessageType('ReplyFansDetail', (_message.Message,), {
  'DESCRIPTOR' : _REPLYFANSDETAIL,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyFansDetail)
  })
_sym_db.RegisterMessage(ReplyFansDetail)

ReplyFolder = _reflection.GeneratedProtocolMessageType('ReplyFolder', (_message.Message,), {
  'DESCRIPTOR' : _REPLYFOLDER,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyFolder)
  })
_sym_db.RegisterMessage(ReplyFolder)

ReplyLabel = _reflection.GeneratedProtocolMessageType('ReplyLabel', (_message.Message,), {
  'DESCRIPTOR' : _REPLYLABEL,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyLabel)
  })
_sym_db.RegisterMessage(ReplyLabel)

ReplyLevelInfo = _reflection.GeneratedProtocolMessageType('ReplyLevelInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLYLEVELINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyLevelInfo)
  })
_sym_db.RegisterMessage(ReplyLevelInfo)

ReplyMember = _reflection.GeneratedProtocolMessageType('ReplyMember', (_message.Message,), {
  'DESCRIPTOR' : _REPLYMEMBER,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyMember)
  })
_sym_db.RegisterMessage(ReplyMember)

ReplyMemberInfo = _reflection.GeneratedProtocolMessageType('ReplyMemberInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPLYMEMBERINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyMemberInfo)
  })
_sym_db.RegisterMessage(ReplyMemberInfo)

ReplyPage = _reflection.GeneratedProtocolMessageType('ReplyPage', (_message.Message,), {
  'DESCRIPTOR' : _REPLYPAGE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyPage)
  })
_sym_db.RegisterMessage(ReplyPage)

ReplyUpAction = _reflection.GeneratedProtocolMessageType('ReplyUpAction', (_message.Message,), {
  'DESCRIPTOR' : _REPLYUPACTION,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyUpAction)
  })
_sym_db.RegisterMessage(ReplyUpAction)

ReplyVip = _reflection.GeneratedProtocolMessageType('ReplyVip', (_message.Message,), {
  'DESCRIPTOR' : _REPLYVIP,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyVip)
  })
_sym_db.RegisterMessage(ReplyVip)

ReplyVote = _reflection.GeneratedProtocolMessageType('ReplyVote', (_message.Message,), {
  'DESCRIPTOR' : _REPLYVOTE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReplyVote)
  })
_sym_db.RegisterMessage(ReplyVote)

ReqUser = _reflection.GeneratedProtocolMessageType('ReqUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUSER,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReqUser)
  })
_sym_db.RegisterMessage(ReqUser)

ReserveActivityParam = _reflection.GeneratedProtocolMessageType('ReserveActivityParam', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEACTIVITYPARAM,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ReserveActivityParam)
  })
_sym_db.RegisterMessage(ReserveActivityParam)

Rights = _reflection.GeneratedProtocolMessageType('Rights', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTS,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Rights)
  })
_sym_db.RegisterMessage(Rights)

SeasonEpisode = _reflection.GeneratedProtocolMessageType('SeasonEpisode', (_message.Message,), {
  'DESCRIPTOR' : _SEASONEPISODE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.SeasonEpisode)
  })
_sym_db.RegisterMessage(SeasonEpisode)

SeasonSection = _reflection.GeneratedProtocolMessageType('SeasonSection', (_message.Message,), {
  'DESCRIPTOR' : _SEASONSECTION,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.SeasonSection)
  })
_sym_db.RegisterMessage(SeasonSection)

SeasonStat = _reflection.GeneratedProtocolMessageType('SeasonStat', (_message.Message,), {
  'DESCRIPTOR' : _SEASONSTAT,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.SeasonStat)
  })
_sym_db.RegisterMessage(SeasonStat)

Space = _reflection.GeneratedProtocolMessageType('Space', (_message.Message,), {
  'DESCRIPTOR' : _SPACE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Space)
  })
_sym_db.RegisterMessage(Space)

Staff = _reflection.GeneratedProtocolMessageType('Staff', (_message.Message,), {
  'DESCRIPTOR' : _STAFF,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Staff)
  })
_sym_db.RegisterMessage(Staff)

StaffInfo = _reflection.GeneratedProtocolMessageType('StaffInfo', (_message.Message,), {
  'DESCRIPTOR' : _STAFFINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.StaffInfo)
  })
_sym_db.RegisterMessage(StaffInfo)

Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
  'DESCRIPTOR' : _STAT,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Stat)
  })
_sym_db.RegisterMessage(Stat)

Subtitle = _reflection.GeneratedProtocolMessageType('Subtitle', (_message.Message,), {
  'DESCRIPTOR' : _SUBTITLE,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Subtitle)
  })
_sym_db.RegisterMessage(Subtitle)

SubtitleItem = _reflection.GeneratedProtocolMessageType('SubtitleItem', (_message.Message,), {
  'DESCRIPTOR' : _SUBTITLEITEM,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.SubtitleItem)
  })
_sym_db.RegisterMessage(SubtitleItem)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.Tag)
  })
_sym_db.RegisterMessage(Tag)

TagCount = _reflection.GeneratedProtocolMessageType('TagCount', (_message.Message,), {
  'DESCRIPTOR' : _TAGCOUNT,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.TagCount)
  })
_sym_db.RegisterMessage(TagCount)

UGCPayAsset = _reflection.GeneratedProtocolMessageType('UGCPayAsset', (_message.Message,), {

  'PlatformPriceEntry' : _reflection.GeneratedProtocolMessageType('PlatformPriceEntry', (_message.Message,), {
    'DESCRIPTOR' : _UGCPAYASSET_PLATFORMPRICEENTRY,
    '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.UGCPayAsset.PlatformPriceEntry)
    })
  ,
  'DESCRIPTOR' : _UGCPAYASSET,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.UGCPayAsset)
  })
_sym_db.RegisterMessage(UGCPayAsset)
_sym_db.RegisterMessage(UGCPayAsset.PlatformPriceEntry)

UGCSeason = _reflection.GeneratedProtocolMessageType('UGCSeason', (_message.Message,), {
  'DESCRIPTOR' : _UGCSEASON,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.UGCSeason)
  })
_sym_db.RegisterMessage(UGCSeason)

View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
  'DESCRIPTOR' : _VIEW,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.View)
  })
_sym_db.RegisterMessage(View)

ViewDetailReply = _reflection.GeneratedProtocolMessageType('ViewDetailReply', (_message.Message,), {
  'DESCRIPTOR' : _VIEWDETAILREPLY,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ViewDetailReply)
  })
_sym_db.RegisterMessage(ViewDetailReply)

ViewDetailReq = _reflection.GeneratedProtocolMessageType('ViewDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _VIEWDETAILREQ,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ViewDetailReq)
  })
_sym_db.RegisterMessage(ViewDetailReq)

ViewLabel = _reflection.GeneratedProtocolMessageType('ViewLabel', (_message.Message,), {
  'DESCRIPTOR' : _VIEWLABEL,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.ViewLabel)
  })
_sym_db.RegisterMessage(ViewLabel)

VipInfo = _reflection.GeneratedProtocolMessageType('VipInfo', (_message.Message,), {
  'DESCRIPTOR' : _VIPINFO,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.VipInfo)
  })
_sym_db.RegisterMessage(VipInfo)

VipLabel = _reflection.GeneratedProtocolMessageType('VipLabel', (_message.Message,), {
  'DESCRIPTOR' : _VIPLABEL,
  '__module__' : 'bilibili.web.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.web.interfaces.v1.VipLabel)
  })
_sym_db.RegisterMessage(VipLabel)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTIVITYTHEME_KVCOLORENTRY._options = None
  _ACTIVITYTHEME_KVCOLORENTRY._serialized_options = b'8\001'
  _REPLYCONTENT_EMOTEENTRY._options = None
  _REPLYCONTENT_EMOTEENTRY._serialized_options = b'8\001'
  _UGCPAYASSET_PLATFORMPRICEENTRY._options = None
  _UGCPAYASSET_PLATFORMPRICEENTRY._serialized_options = b'8\001'
  _ACTIVITYSEASONSTATUS._serialized_start=13476
  _ACTIVITYSEASONSTATUS._serialized_end=13546
  _ORDERTYPE._serialized_start=13548
  _ORDERTYPE._serialized_end=13630
  _REPLYEMOTEMETASIZE._serialized_start=13632
  _REPLYEMOTEMETASIZE._serialized_end=13737
  _ACCINFO._serialized_start=75
  _ACCINFO._serialized_end=152
  _ACCOUNTCARD._serialized_start=155
  _ACCOUNTCARD._serialized_end=679
  _ACTIVITYARCHIVEREPLY._serialized_start=682
  _ACTIVITYARCHIVEREPLY._serialized_end=1053
  _ACTIVITYARCHIVEREQ._serialized_start=1055
  _ACTIVITYARCHIVEREQ._serialized_end=1124
  _ACTIVITYEPISODE._serialized_start=1127
  _ACTIVITYEPISODE._serialized_end=1330
  _ACTIVITYGAME._serialized_start=1332
  _ACTIVITYGAME._serialized_end=1455
  _ACTIVITYGAMEIFRAME._serialized_start=1457
  _ACTIVITYGAMEIFRAME._serialized_end=1506
  _ACTIVITYLIVE._serialized_start=1509
  _ACTIVITYLIVE._serialized_end=1879
  _ACTIVITYLIVETIMEINFOREPLY._serialized_start=1882
  _ACTIVITYLIVETIMEINFOREPLY._serialized_end=2025
  _ACTIVITYLIVETIMEINFOREQ._serialized_start=2027
  _ACTIVITYLIVETIMEINFOREQ._serialized_end=2074
  _ACTIVITYSEASONREPLY._serialized_start=2077
  _ACTIVITYSEASONREPLY._serialized_end=2471
  _ACTIVITYSEASONREQ._serialized_start=2473
  _ACTIVITYSEASONREQ._serialized_end=2541
  _ACTIVITYSEASONSECTION._serialized_start=2543
  _ACTIVITYSEASONSECTION._serialized_end=2670
  _ACTIVITYSUBSCRIBE._serialized_start=2673
  _ACTIVITYSUBSCRIBE._serialized_end=3123
  _ACTIVITYTHEME._serialized_start=3126
  _ACTIVITYTHEME._serialized_end=3925
  _ACTIVITYTHEME_KVCOLORENTRY._serialized_start=3879
  _ACTIVITYTHEME_KVCOLORENTRY._serialized_end=3925
  _ACTIVITYVIEW._serialized_start=3928
  _ACTIVITYVIEW._serialized_end=4360
  _ARC._serialized_start=4363
  _ARC._serialized_end=5098
  _AUTHOR._serialized_start=5100
  _AUTHOR._serialized_end=5149
  _CARD._serialized_start=5152
  _CARD._serialized_end=5346
  _CARDLEVELINFO._serialized_start=5348
  _CARDLEVELINFO._serialized_end=5424
  _CARDVIP._serialized_start=5427
  _CARDVIP._serialized_end=5558
  _CLICKACTIVITYSEASONREQ._serialized_start=5561
  _CLICKACTIVITYSEASONREQ._serialized_end=5908
  _DESCV2._serialized_start=5910
  _DESCV2._serialized_end=5966
  _DIMENSION._serialized_start=5968
  _DIMENSION._serialized_end=6026
  _FAVSEASONPARAM._serialized_start=6028
  _FAVSEASONPARAM._serialized_end=6063
  _HOTREPLY._serialized_start=6065
  _HOTREPLY._serialized_end=6180
  _JUMPURLPARAM._serialized_start=6182
  _JUMPURLPARAM._serialized_end=6214
  _LIVETIMELINE._serialized_start=6216
  _LIVETIMELINE._serialized_end=6333
  _NAMEPLATEINFO._serialized_start=6335
  _NAMEPLATEINFO._serialized_end=6447
  _NOREPLY._serialized_start=6449
  _NOREPLY._serialized_end=6458
  _OFFICIALINFO._serialized_start=6460
  _OFFICIALINFO._serialized_end=6517
  _OFFICIALVERIFY._serialized_start=6519
  _OFFICIALVERIFY._serialized_end=6563
  _OPERATIONRELATE._serialized_start=6566
  _OPERATIONRELATE._serialized_end=6719
  _PAGE._serialized_start=6722
  _PAGE._serialized_end=6903
  _PENDANTINFO._serialized_start=6905
  _PENDANTINFO._serialized_end=6976
  _RELATE._serialized_start=6978
  _RELATE._serialized_end=7067
  _RELATEITEM._serialized_start=7069
  _RELATEITEM._serialized_end=7109
  _RELATION._serialized_start=7111
  _RELATION._serialized_end=7157
  _REPLY._serialized_start=7160
  _REPLY._serialized_end=7895
  _REPLYCONTENT._serialized_start=7898
  _REPLYCONTENT._serialized_end=8288
  _REPLYCONTENT_EMOTEENTRY._serialized_start=8204
  _REPLYCONTENT_EMOTEENTRY._serialized_end=8288
  _REPLYEMOTE._serialized_start=8291
  _REPLYEMOTE._serialized_end=8493
  _REPLYEMOTEMETA._serialized_start=8495
  _REPLYEMOTEMETA._serialized_end=8573
  _REPLYFANSDETAIL._serialized_start=8576
  _REPLYFANSDETAIL._serialized_end=8726
  _REPLYFOLDER._serialized_start=8728
  _REPLYFOLDER._serialized_end=8794
  _REPLYLABEL._serialized_start=8797
  _REPLYLABEL._serialized_end=8970
  _REPLYLEVELINFO._serialized_start=8972
  _REPLYLEVELINFO._serialized_end=9049
  _REPLYMEMBER._serialized_start=9052
  _REPLYMEMBER._serialized_end=9209
  _REPLYMEMBERINFO._serialized_start=9212
  _REPLYMEMBERINFO._serialized_end=9653
  _REPLYPAGE._serialized_start=9655
  _REPLYPAGE._serialized_end=9724
  _REPLYUPACTION._serialized_start=9726
  _REPLYUPACTION._serialized_end=9770
  _REPLYVIP._serialized_start=9773
  _REPLYVIP._serialized_end=9976
  _REPLYVOTE._serialized_start=9978
  _REPLYVOTE._serialized_end=10060
  _REQUSER._serialized_start=10062
  _REQUSER._serialized_end=10138
  _RESERVEACTIVITYPARAM._serialized_start=10140
  _RESERVEACTIVITYPARAM._serialized_end=10223
  _RIGHTS._serialized_start=10226
  _RIGHTS._serialized_end=10423
  _SEASONEPISODE._serialized_start=10426
  _SEASONEPISODE._serialized_end=10660
  _SEASONSECTION._serialized_start=10663
  _SEASONSECTION._serialized_end=10799
  _SEASONSTAT._serialized_start=10802
  _SEASONSTAT._serialized_end=10971
  _SPACE._serialized_start=10973
  _SPACE._serialized_end=11010
  _STAFF._serialized_start=11013
  _STAFF._serialized_end=11281
  _STAFFINFO._serialized_start=11283
  _STAFFINFO._serialized_end=11322
  _STAT._serialized_start=11325
  _STAT._serialized_end=11538
  _SUBTITLE._serialized_start=11540
  _SUBTITLE._serialized_end=11628
  _SUBTITLEITEM._serialized_start=11631
  _SUBTITLEITEM._serialized_end=11799
  _TAG._serialized_start=11802
  _TAG._serialized_end=12106
  _TAGCOUNT._serialized_start=12108
  _TAGCOUNT._serialized_end=12160
  _UGCPAYASSET._serialized_start=12163
  _UGCPAYASSET._serialized_end=12329
  _UGCPAYASSET_PLATFORMPRICEENTRY._serialized_start=12277
  _UGCPAYASSET_PLATFORMPRICEENTRY._serialized_end=12329
  _UGCSEASON._serialized_start=12332
  _UGCSEASON._serialized_end=12606
  _VIEW._serialized_start=12609
  _VIEW._serialized_end=13028
  _VIEWDETAILREPLY._serialized_start=13031
  _VIEWDETAILREPLY._serialized_end=13294
  _VIEWDETAILREQ._serialized_start=13296
  _VIEWDETAILREQ._serialized_end=13338
  _VIEWLABEL._serialized_start=13340
  _VIEWLABEL._serialized_end=13365
  _VIPINFO._serialized_start=13367
  _VIPINFO._serialized_end=13448
  _VIPLABEL._serialized_start=13450
  _VIPLABEL._serialized_end=13474
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class NativePageEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGEID_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    PageID: builtins.int
    """Native页ID"""

    @property
    def Items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventItem]:
        """"""
        pass
    def __init__(self,
        *,
        PageID: builtins.int = ...,
        Items: typing.Optional[typing.Iterable[global___EventItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Items",b"Items","PageID",b"PageID"]) -> None: ...
global___NativePageEvent = NativePageEvent

class EventItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    DISPLAYNUM_FIELD_NUMBER: builtins.int
    WEBKEY_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    ItemID: builtins.int
    """组件标识"""

    Type: typing.Text
    """组件类型"""

    Num: builtins.int
    """进度条数值"""

    DisplayNum: typing.Text
    """进度条展示数值"""

    WebKey: typing.Text
    """h5的组件标识"""

    dimension: builtins.int
    """活动统计维度
    0:用户维度 1:规则维度
    """

    def __init__(self,
        *,
        ItemID: builtins.int = ...,
        Type: typing.Text = ...,
        Num: builtins.int = ...,
        DisplayNum: typing.Text = ...,
        WebKey: typing.Text = ...,
        dimension: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["DisplayNum",b"DisplayNum","ItemID",b"ItemID","Num",b"Num","Type",b"Type","WebKey",b"WebKey","dimension",b"dimension"]) -> None: ...
global___EventItem = EventItem



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/im/notify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/broadcast/message/im/notify.proto\x12\x1d\x62ilibili.broadcast.message.im\x1a\x1bgoogle/protobuf/empty.proto\"s\n\tNotifyRsp\x12\x0b\n\x03uid\x18\x01 \x01(\x04\x12\x0b\n\x03\x63md\x18\x02 \x01(\x04\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12;\n\x0cpayload_type\x18\x04 \x01(\x0e\x32%.bilibili.broadcast.message.im.PLType\"\xd8\x02\n\x03Msg\x12\x12\n\nsender_uid\x18\x01 \x01(\x04\x12\x15\n\rreceiver_type\x18\x02 \x01(\x05\x12\x13\n\x0breceiver_id\x18\x03 \x01(\x04\x12\x12\n\ncli_msg_id\x18\x04 \x01(\x04\x12\x10\n\x08msg_type\x18\x05 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\x11\n\tmsg_seqno\x18\x07 \x01(\x04\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12\x0f\n\x07\x61t_uids\x18\t \x03(\x04\x12\x12\n\nrecver_ids\x18\n \x03(\x04\x12\x0f\n\x07msg_key\x18\x0b \x01(\x04\x12\x12\n\nmsg_status\x18\x0c \x01(\r\x12\x12\n\nsys_cancel\x18\r \x01(\x08\x12\x15\n\ris_multi_chat\x18\x0e \x01(\r\x12\x16\n\x0ewithdraw_seqno\x18\x0f \x01(\x04\x12\x13\n\x0bnotify_code\x18\x10 \x01(\t\x12\x12\n\nmsg_source\x18\x11 \x01(\r\"G\n\nNotifyInfo\x12\x10\n\x08msg_type\x18\x01 \x01(\r\x12\x11\n\ttalker_id\x18\x02 \x01(\x04\x12\x14\n\x0csession_type\x18\x03 \x01(\r\"\xa1\x01\n\x0fReqServerNotify\x12\x15\n\rlastest_seqno\x18\x01 \x01(\x04\x12\x37\n\x0binstant_msg\x18\x02 \x01(\x0b\x32\".bilibili.broadcast.message.im.Msg\x12>\n\x0bnotify_info\x18\x03 \x01(\x0b\x32).bilibili.broadcast.message.im.NotifyInfo*6\n\x06PLType\x12\x15\n\x11\x45N_PAYLOAD_NORMAL\x10\x00\x12\x15\n\x11\x45N_PAYLOAD_BASE64\x10\x01*P\n\x05\x43mdId\x12\x15\n\x11\x45N_CMD_ID_INVALID\x10\x00\x12\x18\n\x14\x45N_CMD_ID_MSG_NOTIFY\x10\x01\x12\x16\n\x12\x45N_CMD_ID_KICK_OUT\x10\x02\x32[\n\x06Notify\x12Q\n\x0bWatchNotify\x12\x16.google.protobuf.Empty\x1a(.bilibili.broadcast.message.im.NotifyRsp0\x01\x62\x06proto3')

_PLTYPE = DESCRIPTOR.enum_types_by_name['PLType']
PLType = enum_type_wrapper.EnumTypeWrapper(_PLTYPE)
_CMDID = DESCRIPTOR.enum_types_by_name['CmdId']
CmdId = enum_type_wrapper.EnumTypeWrapper(_CMDID)
EN_PAYLOAD_NORMAL = 0
EN_PAYLOAD_BASE64 = 1
EN_CMD_ID_INVALID = 0
EN_CMD_ID_MSG_NOTIFY = 1
EN_CMD_ID_KICK_OUT = 2


_NOTIFYRSP = DESCRIPTOR.message_types_by_name['NotifyRsp']
_MSG = DESCRIPTOR.message_types_by_name['Msg']
_NOTIFYINFO = DESCRIPTOR.message_types_by_name['NotifyInfo']
_REQSERVERNOTIFY = DESCRIPTOR.message_types_by_name['ReqServerNotify']
NotifyRsp = _reflection.GeneratedProtocolMessageType('NotifyRsp', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYRSP,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.NotifyRsp)
  })
_sym_db.RegisterMessage(NotifyRsp)

Msg = _reflection.GeneratedProtocolMessageType('Msg', (_message.Message,), {
  'DESCRIPTOR' : _MSG,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.Msg)
  })
_sym_db.RegisterMessage(Msg)

NotifyInfo = _reflection.GeneratedProtocolMessageType('NotifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYINFO,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.NotifyInfo)
  })
_sym_db.RegisterMessage(NotifyInfo)

ReqServerNotify = _reflection.GeneratedProtocolMessageType('ReqServerNotify', (_message.Message,), {
  'DESCRIPTOR' : _REQSERVERNOTIFY,
  '__module__' : 'bilibili.broadcast.message.im.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.im.ReqServerNotify)
  })
_sym_db.RegisterMessage(ReqServerNotify)

_NOTIFY = DESCRIPTOR.services_by_name['Notify']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLTYPE._serialized_start=807
  _PLTYPE._serialized_end=861
  _CMDID._serialized_start=863
  _CMDID._serialized_end=943
  _NOTIFYRSP._serialized_start=106
  _NOTIFYRSP._serialized_end=221
  _MSG._serialized_start=224
  _MSG._serialized_end=568
  _NOTIFYINFO._serialized_start=570
  _NOTIFYINFO._serialized_end=641
  _REQSERVERNOTIFY._serialized_start=644
  _REQSERVERNOTIFY._serialized_end=805
  _NOTIFY._serialized_start=945
  _NOTIFY._serialized_end=1036
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Status(google.protobuf.message.Message):
    """响应gRPC Status
    当status code是[UNKNOWN = 2]时，details为业务详细的错误信息，进行proto any转换成业务码结构体
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    code: builtins.int
    """业务错误码"""

    message: typing.Text
    """业务错误信息"""

    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """扩展信息嵌套(相当于该messasge的套娃)"""
        pass
    def __init__(self,
        *,
        code: builtins.int = ...,
        message: typing.Text = ...,
        details: typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code",b"code","details",b"details","message",b"message"]) -> None: ...
global___Status = Status



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PremiereStatusReq(google.protobuf.message.Message):
    """获取首播状态-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EP_ID_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """剧集epid"""

    def __init__(self,
        *,
        ep_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ep_id",b"ep_id"]) -> None: ...
global___PremiereStatusReq = PremiereStatusReq

class PremiereStatusReply(google.protobuf.message.Message):
    """获取首播状态-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROGRESS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    DELAY_TIME_FIELD_NUMBER: builtins.int
    ONLINE_COUNT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    AFTER_PREMIERE_TYPE_FIELD_NUMBER: builtins.int
    progress: builtins.int
    """服务端播放进度 单位ms 用户实际播放进度：progress - delay_time"""

    start_time: builtins.int
    """起播时间戳 单位ms"""

    delay_time: builtins.int
    """延迟播放时长 单位ms"""

    online_count: builtins.int
    """首播在线人数"""

    status: builtins.int
    """首播状态
    1:预热 2:首播中 3:紧急停播 4:已结束
    """

    after_premiere_type: builtins.int
    """首播结束后跳转类型
    1:下架 2:转点播
    """

    def __init__(self,
        *,
        progress: builtins.int = ...,
        start_time: builtins.int = ...,
        delay_time: builtins.int = ...,
        online_count: builtins.int = ...,
        status: builtins.int = ...,
        after_premiere_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_premiere_type",b"after_premiere_type","delay_time",b"delay_time","online_count",b"online_count","progress",b"progress","start_time",b"start_time","status",b"status"]) -> None: ...
global___PremiereStatusReply = PremiereStatusReply



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ModResourceResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATCION_FIELD_NUMBER: builtins.int
    APP_KEY_FIELD_NUMBER: builtins.int
    POOL_NAME_FIELD_NUMBER: builtins.int
    MODULE_NAME_FIELD_NUMBER: builtins.int
    MODULE_VERSION_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    atcion: builtins.int
    """"""

    app_key: typing.Text
    """"""

    pool_name: typing.Text
    """"""

    module_name: typing.Text
    """"""

    module_version: builtins.int
    """"""

    list_version: builtins.int
    """"""

    def __init__(self,
        *,
        atcion: builtins.int = ...,
        app_key: typing.Text = ...,
        pool_name: typing.Text = ...,
        module_name: typing.Text = ...,
        module_version: builtins.int = ...,
        list_version: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_key",b"app_key","atcion",b"atcion","list_version",b"list_version","module_name",b"module_name","module_version",b"module_version","pool_name",b"pool_name"]) -> None: ...
global___ModResourceResp = ModResourceResp



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.interfaces.v1 import search_pb2 as bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2


class SearchStub(object):
    """搜索
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Suggest3 = channel.unary_unary(
                '/bilibili.app.interfaces.v1.Search/Suggest3',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2.SuggestionResult3Req.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2.SuggestionResult3Reply.FromString,
                )


class SearchServicer(object):
    """搜索
    """

    def Suggest3(self, request, context):
        """获取搜索建议
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Suggest3': grpc.unary_unary_rpc_method_handler(
                    servicer.Suggest3,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2.SuggestionResult3Req.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2.SuggestionResult3Reply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.interfaces.v1.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """搜索
    """

    @staticmethod
    def Suggest3(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interfaces.v1.Search/Suggest3',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2.SuggestionResult3Req.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_search__pb2.SuggestionResult3Reply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from ..utils import get

BASE_URL = "https://api.vc.bilibili.com"


async def get_user_dynamics(
    uid: int,
    offset: int = 0,
    need_top: bool = False,
    *,
    auth=None,
    reqtype="app",
    **kwargs,
):
    """获取指定用户历史动态"""
    url = f"{BASE_URL}/dynamic_svr/v1/dynamic_svr/space_history"
    params = {
        "host_uid": uid,
        "offset_dynamic_id": offset,
        "need_top": int(bool(need_top)),
    }
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)


async def get_followed_new_dynamics(*, auth, reqtype="web", **kwargs):
    """获取最新关注动态"""
    url = f"{BASE_URL}/dynamic_svr/v1/dynamic_svr/dynamic_new"
    params = {
        "type_list": 268435455,
    }
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)


async def get_followed_history_dynamics(offset: int, *, auth, reqtype="web", **kwargs):
    """获取历史关注动态"""
    url = f"{BASE_URL}/dynamic_svr/v1/dynamic_svr/dynamic_history"
    params = {
        "type_list": 268435455,
        "offset_dynamic_id": offset,
    }
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)


async def get_followed_dynamics_update_info(offset=0, *, auth, reqtype="web", **kwargs):
    """获取关注动态更新信息"""
    url = f"{BASE_URL}/dynamic_svr/v1/dynamic_svr/web_cyclic_num"
    params = {
        "type_list": 268435455,
        "offset": offset,
    }
    return await get(url, params=params, auth=auth, reqtype=reqtype, **kwargs)
